@@ -3,6 +3,7 @@
 # @IDE      : PyCharm
 # @Author   : Angel
 # @Email    : 376355670@qq.com
+from abc import ABCMeta, abstractmethod
 from typing import TypeVar
 
 """
@@ -12,46 +13,33 @@ from typing import TypeVar
 T = TypeVar("T")
 
 
-class IWorker(object):
+class IWorker(metaclass=ABCMeta):
     """
     worker interface
     """
 
+    @abstractmethod
     async def start(self) -> T:
         raise NotImplementedError("NotImplemented .start() -> T")
 
 
-class IWorkerGroup(object):
-    """
-    worker group interface
-    """
-
-    def stuff(self, workers: T) -> None:
-        """
-        stuff workers
-        :param workers:
-        :return:
-        """
-        raise NotImplementedError("NotImplemented .stuff(workers) -> None")
-
-    async def start(self) -> T:
-        raise NotImplementedError("NotImplemented .start() -> T")
-
-
-class IWorkerMaster(object):
+class IWorkerMaster(metaclass=ABCMeta):
     """
     worker master interface
     """
 
-    def add(self, worker_or_group: T):
+    @abstractmethod
+    def add(self, worker: IWorker):
         raise NotImplementedError("NotImplemented .add(worker_or_group)")
 
+    @abstractmethod
     def start(self) -> T:
         raise NotImplementedError("NotImplemented .start() -> T")
 
 
-class IFactory(object):
+class IWorkerFactory(metaclass=ABCMeta):
 
     @classmethod
-    def create(cls, *args, **kwargs):
+    @abstractmethod
+    def create(cls, *args, **kwargs) -> T:
         raise NotImplementedError("NotImplemented .create() -> T")
